==> piwigo-v2.10.2.zip: piwigo/language/br_FR/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = 'Ar bajenn-mañ a ginnig hizivadur an diaz roadennoù eus ho stumm Piwigo kozh d\'ar stumm nevez. An ameiler hizivaat a soñj emañ <strong>stumm %s</strong> o labourat (pe gevatal).';
$lang['User permissions and group permissions have been erased'] = 'Implijerien ha strolladoù a zo bet dilemet';
$lang['You do not have access rights to run upgrade'] = 'Difennet eo deoc\'h hizivaat';
$lang['Statistics'] = 'Stadegoù';
$lang['total upgrade time'] = 'Hollad amzer an hizivadur';
$lang['Upgrade'] = 'Hizivadur';
$lang['Upgrade from version %s to %s'] = 'Hizivaat eus stumm %s betek %s';
$lang['Upgrade informations'] = 'Titouroù hizivadur';
$lang['total SQL time'] = 'Hollad an amzer SQL ';
$lang['SQL queries'] = 'Rekedoù SQL';
$lang['Only administrator can run upgrade: please sign in below.'] = 'Ret eo bezañ merour evit hizivaat: kevreit amañ dindan mar plij.';
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = 'Gwiriit an trezalc\'h e [Mererezh>Ostilhoù>Trezalc\'h] m\'ho peus kudennoù.';
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = 'Nemet rakger ar skeudennoùigoù ha postel ar mestr-gwiad a zo bet saveteet eus ar c\'hefluniadur kozh';
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = 'E <i>%s</i>, a-raok <b>?></b>, lakaat:';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = 'Evit diwall, an tenoù-se a zo bet diweredekaet. Ret e vo deoc\'h sellout ma\'z eus temoù da hizivaat a-raok gweredekaat anezho en-dro.';
$lang['All sub-albums of private albums become private'] = 'An holl iz-rummadoù e-barzh rummadoù prevez a vo prevez';
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = 'Evit diwall, al lugantoù-se a zo bet diweredekaet. Ret e vo deoc\'h sellout ma\'z eus lugantoù da hizivaat a-raok gweredekaat anezho en-dro.';
$lang['Discover what\'s new in Piwigo %s'] = 'Dizoleiñ petra nevez \'z eus e Piwigo %s';

==> piwigo-15.6.0.zip: piwigo/language/br_FR/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = 'Ar bajenn-mañ a ginnig hizivadur an diaz roadennoù eus ho stumm Piwigo kozh d\'ar stumm nevez. An ameiler hizivaat a soñj emañ <strong>stumm %s</strong> o labourat (pe gevatal).';
$lang['User permissions and group permissions have been erased'] = 'Implijerien ha strolladoù a zo bet dilemet';
$lang['You do not have access rights to run upgrade'] = 'Difennet eo deoc\'h hizivaat';
$lang['Statistics'] = 'Stadegoù';
$lang['total upgrade time'] = 'Hollad amzer an hizivadur';
$lang['Upgrade'] = 'Hizivadur';
$lang['Upgrade from version %s to %s'] = 'Hizivaat eus stumm %s betek %s';
$lang['Upgrade informations'] = 'Titouroù hizivadur';
$lang['total SQL time'] = 'Hollad an amzer SQL ';
$lang['SQL queries'] = 'Rekedoù SQL';
$lang['Only administrator can run upgrade: please sign in below.'] = 'Ar verourien hepken a c\'hall hizivaat: kevreit amañ dindan, mar plij.';
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = 'Gwiriit an trezalc\'h e [Mererezh>Ostilhoù>Trezalc\'h] m\'ho peus kudennoù.';
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = 'N\'eus nemet rakger ar skeudennoùigoù ha postel ar mestr-gwiad hag a zo bet saveteet eus ar c\'hefluniadur kozh';
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = 'E <i>%s</i>, a-raok <b>?></b>, lakaat:';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = 'An temoù-se a zo bet diweredekaet e kenkaz. Ret e vo deoc\'h sellout hag-eñ ez eus temoù da hizivaat a-raok gweredekaat anezho en-dro.';
$lang['All sub-albums of private albums become private'] = 'Hollad iz-albomoù an albomoù prevez a zeuio da vezañ prevez';
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = 'Al lugantoù-se a zo bet diweredekaet e kenkaz. Ret e vo deoc\'h sellout hag-eñ ez eus lugantoù da hizivaat a-raok gweredekaat anezho en-dro.';
$lang['Discover what\'s new in Piwigo %s'] = 'Dizoleiñ petra \'zo nevez e Piwigo %s';
